@@ -53,14 +53,18 @@ MODES = ["GMT_CONTAINER_ONLY", "GMT_IS_OUTPUT"]
 REGISTRATIONS = ["GMT_GRID_PIXEL_REG", "GMT_GRID_NODE_REG"]
 
 DTYPES = {
-    np.float64: "GMT_DOUBLE",
-    np.float32: "GMT_FLOAT",
-    np.int64: "GMT_LONG",
+    np.int8: "GMT_CHAR",
+    np.int16: "GMT_SHORT",
     np.int32: "GMT_INT",
-    np.uint64: "GMT_ULONG",
+    np.int64: "GMT_LONG",
+    np.uint8: "GMT_UCHAR",
+    np.uint16: "GMT_USHORT",
     np.uint32: "GMT_UINT",
-    np.datetime64: "GMT_DATETIME",
+    np.uint64: "GMT_ULONG",
+    np.float32: "GMT_FLOAT",
+    np.float64: "GMT_DOUBLE",
     np.str_: "GMT_TEXT",
+    np.datetime64: "GMT_DATETIME",
 }
 
 
@@ -732,8 +736,8 @@ class Session:
         The dataset must be created by :meth:`pygmt.clib.Session.create_data`
         first. Use ``family='GMT_IS_DATASET|GMT_VIA_VECTOR'``.
 
-        Not at all numpy dtypes are supported, only: float64, float32, int64,
-        int32, uint64, uint32, datetime64 and str\_.
+        Not all numpy dtypes are supported, only: int8, int16, int32, int64,
+        uint8, uint16, uint32, uint64, float32, float64, str\_ and datetime64.
 
         .. warning::
             The numpy array must be C contiguous in memory. If it comes from a
@@ -856,8 +860,8 @@ class Session:
         The dataset must be created by :meth:`pygmt.clib.Session.create_data`
         first. Use ``|GMT_VIA_MATRIX'`` in the family.
 
-        Not at all numpy dtypes are supported, only: float64, float32, int64,
-        int32, uint64, and uint32.
+        Not all numpy dtypes are supported, only: int8, int16, int32, int64,
+        uint8, uint16, uint32, uint64, float32 and float64.
 
         .. warning::
             The numpy array must be C contiguous in memory. Use
