@@ -2,17 +2,10 @@
 Histogram - Create a histogram
 """
 from pygmt.clib import Session
-from pygmt.helpers import (
-    build_arg_string,
-    deprecate_parameter,
-    fmt_docstring,
-    kwargs_to_strings,
-    use_alias,
-)
+from pygmt.helpers import build_arg_string, fmt_docstring, kwargs_to_strings, use_alias
 
 
 @fmt_docstring
-@deprecate_parameter("table", "data", "v0.5.0", remove_version="v0.7.0")
 @use_alias(
     A="horizontal",
     B="frame",
@@ -148,5 +141,6 @@ def histogram(self, data, **kwargs):
     with Session() as lib:
         file_context = lib.virtualfile_from_data(check_kind="vector", data=data)
         with file_context as infile:
-            arg_str = " ".join([infile, build_arg_string(kwargs)])
-            lib.call_module("histogram", arg_str)
+            lib.call_module(
+                module="histogram", args=build_arg_string(kwargs, infile=infile)
+            )
