@@ -61,4 +61,4 @@ def logo(self, **kwargs):
     """
     kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
     with Session() as lib:
-        lib.call_module("logo", build_arg_string(kwargs))
+        lib.call_module(module="logo", args=build_arg_string(kwargs))
