@@ -12,6 +12,8 @@ from pygmt.helpers import (
 )
 from pygmt.io import load_dataarray
 
+__doctest_skip__ = ["nearneighbor"]
+
 
 @fmt_docstring
 @use_alias(
@@ -131,6 +133,19 @@ def nearneighbor(data=None, x=None, y=None, z=None, **kwargs):
         - :class:`xarray.DataArray`: if ``outgrid`` is not set
         - None if ``outgrid`` is set (grid output will be stored in file set by
           ``outgrid``)
+    Example
+    -------
+    >>> import pygmt
+    >>> # Load a sample dataset of bathymetric x, y, and z values
+    >>> data = pygmt.datasets.load_sample_data(name="bathymetry")
+    >>> # Create a new grid with 5 arc-minute spacing in the designated region
+    >>> # Set search_radius to only consider points within 10 arc-minute of a node
+    >>> output = pygmt.nearneighbor(
+    ...     data=data,
+    ...     spacing="5m",
+    ...     region=[245, 255, 20, 30],
+    ...     search_radius="10m",
+    ... )
     """
     with GMTTempFile(suffix=".nc") as tmpfile:
         with Session() as lib:
@@ -139,10 +154,10 @@ def nearneighbor(data=None, x=None, y=None, z=None, **kwargs):
                 check_kind="vector", data=data, x=x, y=y, z=z, required_z=True
             )
             with table_context as infile:
-                if "G" not in kwargs:  # if outgrid is unset, output to tmpfile
-                    kwargs.update({"G": tmpfile.name})
-                outgrid = kwargs["G"]
-                arg_str = " ".join([infile, build_arg_string(kwargs)])
-                lib.call_module(module="nearneighbor", args=arg_str)
+                if (outgrid := kwargs.get("G")) is None:
+                    kwargs["G"] = outgrid = tmpfile.name  # output to tmpfile
+                lib.call_module(
+                    module="nearneighbor", args=build_arg_string(kwargs, infile=infile)
+                )
 
         return load_dataarray(outgrid) if outgrid == tmpfile.name else None
