@@ -238,8 +238,12 @@ def velo(self, data=None, **kwargs):
     """
     kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
 
-    if "S" not in kwargs or ("S" in kwargs and not isinstance(kwargs["S"], str)):
-        raise GMTInvalidInput("Spec is a required argument and has to be a string.")
+    if kwargs.get("S") is None or (
+        kwargs.get("S") is not None and not isinstance(kwargs["S"], str)
+    ):
+        raise GMTInvalidInput(
+            "The parameter `spec` is required and has to be a string."
+        )
 
     if isinstance(data, np.ndarray) and not pd.api.types.is_numeric_dtype(data):
         raise GMTInvalidInput(
@@ -252,5 +256,4 @@ def velo(self, data=None, **kwargs):
         file_context = lib.virtualfile_from_data(check_kind="vector", data=data)
 
         with file_context as fname:
-            arg_str = " ".join([fname, build_arg_string(kwargs)])
-            lib.call_module("velo", arg_str)
+            lib.call_module(module="velo", args=build_arg_string(kwargs, infile=fname))
