@@ -110,5 +110,4 @@ def x2sys_init(tag, **kwargs):
     {j}
     """
     with Session() as lib:
-        arg_str = " ".join([tag, build_arg_string(kwargs)])
-        lib.call_module(module="x2sys_init", args=arg_str)
+        lib.call_module(module="x2sys_init", args=build_arg_string(kwargs, infile=tag))
